@@ -24,6 +24,7 @@ VERSION = 'v'
 SLOT_VERSION = '2020-12-12'
 UUID = 'id'
 MATCH_SLOT = 'ms'  # ai匹配
+MS_IMAGE_BACKGROUND = 'ms_image_background'
 NAME_SLOT = 'ns'  # 命名替换
 MATCH_UUID = 'm_u'  # 匹配uuid
 REPEAT_MATCH_UUID = 'r_m_u'  # 重复匹配uuid
@@ -34,6 +35,7 @@ COLOR = 'c'  # 颜色
 REPEAT_SLOT_IMG = 'r_s_i'  # 槽内图片是否被其他槽重复使用1次
 REPEAT_SLOT_IMG_INFINITE = 'r_s_i_in'  # 槽内图片是否被其他槽重复使用N次
 REPEAT = 'r'  # 重复替换
+R_IMAGE_BACKGROUND = 'r_image_background'
 STRETCH = 's'  # 是否自适应 fix固定不变  w自适应
 CROP = 'cr'  # 裁剪
 NEED_CROP = 'n_c'  # 0不裁剪  1 裁剪
